import * as http from "node:http";
import { writeBadRequest } from "./http-server.js";

export interface EventServer {
	httpServer: http.Server;
	streams: Set<http.ServerResponse>;
}

export function broadcastMessage(server: EventServer, event: string) {
	for (const stream of server.streams) {
		stream.write(`event: ${event}\ndata\n\n`);
	}
}

function startEventStream(server: EventServer, response: http.ServerResponse) {
	response.statusCode = 200;
	response.statusMessage = "OK";
	response.setHeader("Access-Control-Allow-Origin", "*");
	response.setHeader("Content-Type", "text/event-stream");
	response.flushHeaders();
	server.streams.add(response);
	response.on("close", () => {
		server.streams.delete(response);
	});
}

export function createEventServer() {
	const server = {
		streams: new Set<http.ServerResponse>(),
		httpServer: http.createServer((request, response) => {
			if (request.method === "GET" && request.url === "/events") {
				startEventStream(server, response);
				return;
			}
			writeBadRequest(response, request.method === "HEAD");
		}),
	};
	return server;
}
